package com.bwie.auth.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.auth.feign.UserFeignService;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.User;
import com.bwie.common.domain.request.LoginRequest;
import com.bwie.common.domain.response.TokenResponse;
import com.bwie.common.exception.OverallException;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

/**
 * @Author：张腾
 * @Package：com.bwie.auth.service.impl
 * @Project：Zg6_week02
 * @name：AuthServiceImpl
 * @Date：2024/7/30 9:47
 */
@Service
public class AuthServiceImpl implements AuthService {

    @Autowired
    private UserFeignService userFeignService;

    @Autowired
    private StringRedisTemplate redisTemplate;

    @Autowired
    private HttpServletRequest request;


    @Override
    public Result login(LoginRequest loginRequest) {

        if (StringUtils.isAnyBlank(loginRequest.getUserName(),loginRequest.getUserPwd())){
            throw new OverallException("用户名或密码不能为空");
        }

        Result<User> userResult = userFeignService.selectByName(loginRequest.getUserName());
        User user = userResult.getData();
        if (null == user){
            throw new OverallException("用户不存在,请注册");
        }

        if (!loginRequest.getUserPwd().equals(user.getUserPwd())){
            throw new OverallException("密码错误请检查");
        }
        //生成userKey
        String userKey = UUID.randomUUID().toString().replaceAll("-", "");
        HashMap<String, Object> map = new HashMap<>();
        map.put(JwtConstants.USER_KEY,userKey);
        map.put(JwtConstants.DETAILS_USER_ID,user.getUserId());
        map.put(JwtConstants.DETAILS_USERNAME,user.getUserName());
        //登陆成功,生成token
        String token = JwtUtils.createToken(map);
        //将用户信息存入redis
        redisTemplate.opsForValue().set(TokenConstants.LOGIN_TOKEN_KEY+userKey, JSON.toJSONString(user),30, TimeUnit.MINUTES);
        return Result.success(TokenResponse.builder()
                .token(token)
                .time("30MIN")
                .build());
    }

    @Override
    public Result info() {
        String header = request.getHeader(TokenConstants.TOKEN);
        String userKey = JwtUtils.getUserKey(header);
        String redisUser = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        User user = JSON.parseObject(redisUser, User.class);
        return Result.success(user);
    }
}
