package com.bwie.house.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.House;
import com.bwie.common.domain.Record;
import com.bwie.common.domain.User;
import com.bwie.common.domain.request.HouseReq;
import com.bwie.common.domain.response.HouseResponse;
import com.bwie.common.exception.OverallException;
import com.bwie.common.result.PageResult;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.house.mapper.HouseMapper;
import com.bwie.house.service.HouseService;
import com.bwie.house.service.RecordService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

/**
 * @Author：张腾
 * @Package：com.bwie.house.service.impl
 * @Project：Zg6_week02
 * @name：HouseServiceImpl
 * @Date：2024/7/30 10:24
 */
@Service
public class HouseServiceImpl implements HouseService {

    @Autowired
    private HouseMapper houseMapper;

    @Autowired
    private RecordService recordService;

    @Autowired
    private HttpServletRequest request;

    @Autowired
    private StringRedisTemplate redisTemplate;

    @Override
    public Result<PageResult<HouseResponse>> selectList(HouseReq houseReq) {
        PageHelper.startPage(houseReq.getPageNum(), houseReq.getPageSize());
        List<HouseResponse> list = houseMapper.selectList(houseReq);
        PageInfo<HouseResponse> houseResponsePageInfo = new PageInfo<>(list);
        return PageResult.toResult(houseResponsePageInfo.getTotal(),list);
    }

    @Override
    public Result findById(Integer houseId) {
        House house = houseMapper.findById(houseId);
        String header = request.getHeader(TokenConstants.TOKEN);
        String userKey = JwtUtils.getUserKey(header);
        String redisUser = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        User user = JSON.parseObject(redisUser, User.class);
        List<Record> records = recordService.selectRecordList(user.getUserId());  //根据登录人id查询记录表
        if (CollectionUtils.isNotEmpty(records)){

            for (Record record : records) {
                if (record.getCycleId() == 1){
                    //如果选择的是三个月期限,则过期时间为: 申请时间+3个月
                    int year = record.getApplyDate().getYear()+1900;
                    int expiredDate = record.getApplyDate().getMonth()+3+1; //获取过期月份
                    int day = record.getApplyDate().getDate(); //获取过期当天

                    String date =year+"-"+expiredDate+"-"+day;
                    SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
                    try {
                        Date expire = simpleDateFormat.parse(date);
                        Date now = new Date();
                        if (now.getTime() < expire.getTime()){
                            return Result.error("您的合同未到期暂时不能租房");
                        }
                    } catch (ParseException e) {
                        throw new RuntimeException(e);
                    }
                }
                if (record.getCycleId() == 2){
                    //如果选择的是6个月期限,则过期时间为: 申请时间+6个月
                    int year = record.getApplyDate().getYear()+1900;
                    int expiredDate = record.getApplyDate().getMonth()+6+1; //获取过期月份
                    int day = record.getApplyDate().getDate(); //获取过期当天

                    String date =year+"-"+expiredDate+"-"+day;
                    SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
                    try {
                        Date expire = simpleDateFormat.parse(date);
                        Date now = new Date();
                        if (now.getTime() < expire.getTime()){
                            return Result.error("您的合同未到期暂时不能租房");
                        }
                    } catch (ParseException e) {
                        throw new RuntimeException(e);
                    }
                }
                if (record.getCycleId() == 3){
                    //如果选择的是12个月期限,则过期时间为: 申请时间+1年
                    int year = record.getApplyDate().getYear()+1900+1;
                    int expiredDate = record.getApplyDate().getMonth()+1; //获取过期月份
                    int day = record.getApplyDate().getDate(); //获取过期当天

                    String date =year+"-"+expiredDate+"-"+day;
                    SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
                    try {
                        Date expire = simpleDateFormat.parse(date);
                        Date now = new Date();
                        if (now.getTime() < expire.getTime()){
                            return Result.error("您的合同未到期暂时不能租房");
                        }
                    } catch (ParseException e) {
                        throw new RuntimeException(e);
                    }
                }
                if (record.getCycleId() == 4){
                    //如果选择的是24个月期限,则过期时间为: 申请时间+2年
                    int year = record.getApplyDate().getYear()+1900+2;
                    int expiredDate = record.getApplyDate().getMonth()+1; //获取过期月份
                    int day = record.getApplyDate().getDate(); //获取过期当天

                    String date =year+"-"+expiredDate+"-"+day;
                    SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
                    try {
                        Date expire = simpleDateFormat.parse(date);
                        Date now = new Date();
                        if (now.getTime() < expire.getTime()){
                            return Result.error("您的合同未到期暂时不能租房");
                        }
                    } catch (ParseException e) {
                        throw new RuntimeException(e);
                    }
                }
                if (record.getCycleId() == 5){
                    //如果选择的是36个月期限,则过期时间为: 申请时间+3年
                    int year = record.getApplyDate().getYear()+1900+3;
                    int expiredDate = record.getApplyDate().getMonth()+1; //获取过期月份
                    int day = record.getApplyDate().getDate(); //获取过期当天

                    String date =year+"-"+expiredDate+"-"+day;
                    SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
                    try {
                        Date expire = simpleDateFormat.parse(date);
                        Date now = new Date();
                        if (now.getTime() < expire.getTime()){
                            return Result.error("您的合同未到期暂时不能租房");
                        }
                    } catch (ParseException e) {
                        throw new RuntimeException(e);
                    }
                }
            }

        }
        return Result.success(house);
    }
}
