package com.bwie.house.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.Record;
import com.bwie.common.domain.User;
import com.bwie.common.utils.JwtUtils;
import com.bwie.house.mapper.RecordMapper;
import com.bwie.house.service.RecordService;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @Author：张腾
 * @Package：com.bwie.house.service.impl
 * @Project：Zg6_week02
 * @name：RecordServiceImpl
 * @Date：2024/7/30 12:14
 */
@Service
public class RecordServiceImpl implements RecordService {

    @Autowired
    private RecordMapper recordMapper;

    @Autowired
    private StringRedisTemplate redisTemplate;

    @Autowired
    private HttpServletRequest request;

    @Override
    public List<Record> selectRecordList(Integer userId) {
        return recordMapper.selectRecordList(userId);
    }

    @Override
    public void addRecord(Record record) {
        String header = request.getHeader(TokenConstants.TOKEN);
        String userKey = JwtUtils.getUserKey(header);
        String redisUser = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        User user = JSON.parseObject(redisUser, User.class);
        record.setUserId(user.getUserId());
        List<Record> records = recordMapper.selectRecords();
        if (CollectionUtils.isNotEmpty(records)){
            record.setLoan(record.getPrice());  //不是新用户则不享受打折
        }else{
            record.setLoan(record.getLoanPrice()); //新用户传打折后的钱
        }
        recordMapper.addRecord(record);
    }

    @Override
    public List<Record> recordList() {
        return recordMapper.selectRecords();
    }

    @Override
    public List<Record> selectState() {
        return recordMapper.selectState();
    }

    @Override
    public void updateState(Integer recordId, Integer state) {
        recordMapper.updateState(recordId,state);
    }
}
