package com.bwie.house.sys;

import com.alibaba.fastjson.JSON;
import com.bwie.common.domain.Record;
import com.bwie.common.domain.User;
import com.bwie.house.feign.UserFeignService;
import com.bwie.house.service.RecordService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.UUID;

/**
 * @Author：张腾
 * @Package：com.bwie.house.sys
 * @Project：Zg6_week02
 * @name：CheckApply
 * @Date：2024/7/30 14:24
 */
@Component
@Log4j2
public class CheckApply {

    @Autowired
    private RecordService recordService;

    @Autowired
    private UserFeignService userFeignService;

    @Autowired
    private KafkaTemplate<Object,String> kafkaTemplate;

    @Scheduled(cron = "0/30 * * * * ?")
    @Transactional
    public void checkRecord(){
        log.info("定时任务开始执行...");
        List<Record> records = recordService.selectState();
        //遍历数据库查询state为待审核的用户
        records.forEach(record -> {
            User user = userFeignService.findById(record.getUserId());
            double money = 0.00;
            Integer credit = user.getCredit(); //获取用户信用积分
            for (int i = 0; i <= credit; i+=100) {
                money =money +1000;  //获取用户可用额度
            }

            //根据贷款总价/合约周期计算月供额度是否足够
            if (record.getCycleId() == 1){
                if (record.getLoan()/3 > money){
                        //足够则审核通过
                        recordService.updateState(record.getRecordId(),2);
                }else{
                       //不足够审核驳回
                        recordService.updateState(record.getRecordId(),3);
                        kafkaTemplate.send("TurnDown", UUID.randomUUID(), JSON.toJSONString(record));
                }
            }

            //根据贷款总价/合约周期计算月供额度是否足够
            if (record.getCycleId() == 2){
                if (record.getLoan()/6 > money){
                    //足够则审核通过
                    recordService.updateState(record.getRecordId(),2);
                }else{
                    //不足够审核驳回
                    recordService.updateState(record.getRecordId(),3);
                    kafkaTemplate.send("TurnDown", UUID.randomUUID(), JSON.toJSONString(record));
                }
            }

            //根据贷款总价/合约周期计算月供额度是否足够
            if (record.getCycleId() == 3){
                if (record.getLoan()/12 > money){
                    //足够则审核通过
                    recordService.updateState(record.getRecordId(),2);
                }else{
                    //不足够审核驳回
                    recordService.updateState(record.getRecordId(),3);
                    kafkaTemplate.send("TurnDown", UUID.randomUUID(), JSON.toJSONString(record));
                }
            }

            //根据贷款总价/合约周期计算月供额度是否足够
            if (record.getCycleId() == 4){
                if (record.getLoan()/24 > money){
                    //足够则审核通过
                    recordService.updateState(record.getRecordId(),2);
                }else{
                    //不足够审核驳回
                    recordService.updateState(record.getRecordId(),3);
                    kafkaTemplate.send("TurnDown", UUID.randomUUID(), JSON.toJSONString(record));
                }
            }

            //根据贷款总价/合约周期计算月供额度是否足够
            if (record.getCycleId() == 5){
                if (record.getLoan()/36 > money){
                    //足够则审核通过
                    recordService.updateState(record.getRecordId(),2);
                }else{
                    //不足够审核驳回
                    recordService.updateState(record.getRecordId(),3);
                    kafkaTemplate.send("TurnDown", UUID.randomUUID(), JSON.toJSONString(record));
                }
            }
        });
    }
}
